@@ -6,6 +6,8 @@
 #include <sys/types.h>
 #include <sys/event.h>
 #include <sys/time.h>
+#include <unistd.h>
+#include <fcntl.h>
 #endif
 
 int iom_init(iomux_t* c) {
