@@ -2,10 +2,11 @@
 #define my_extern extern
 #endif
 
-#include "io.h"
-#include "array.h"
-#include "iarray.h"
+#include "libowfat/io.h"
+#include "libowfat/array.h"
+#include "libowfat/iarray.h"
 #ifdef __MINGW32__
+#include <winsock2.h>
 #include "socket.h"
 my_extern HANDLE io_comport;
 #else
@@ -48,6 +49,7 @@ typedef struct {
   unsigned int epolladded:1;
   unsigned int closed:1;	/* io_close called, but close deferred because of outstanding events */
   unsigned int zerocopy:1;	/* linux: setsockopt SO_ZEROCOPY done */
+  unsigned int goterror:1;	/* got POLLERR|POLLHUP */
 #ifdef __MINGW32__
   unsigned int readqueued:2;
   unsigned int writequeued:2;
@@ -83,7 +85,7 @@ my_extern array io_pollfds;
 my_extern long first_readable;
 my_extern long first_writeable;
 
-my_extern long first_deferred;
+extern long first_deferred;
 
 my_extern enum __io_waitmode {
   UNDECIDED,
