@@ -7,8 +7,13 @@ int stralloc_catm_internal(stralloc* sa, ...) {
   const char* s;
   size_t n=0;
   va_start(a,sa);
-  while ((s=va_arg(a,const char*)))
-    n += strlen(s);
+  while ((s=va_arg(a,const char*))) {
+    size_t tmp = strlen(s);
+    if (n + tmp < n) return 0;	// integer overflow
+    // integer overflow should not be possible, but someone could pass
+    // the same string twice to provoke it. Better check than sorry.
+    n += tmp;
+  }
   va_end(a);
   stralloc_readyplus(sa,n);
 
